# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.api.chat_api_api import ChatApiApi


class TestChatApiApi(unittest.IsolatedAsyncioTestCase):
    """ChatApiApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatApiApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_bot_chat_by_topic_slug(self) -> None:
        """Test case for chat_api_bot_chat_by_topic_slug

        Bot Chat By Topic Slug
        """
        pass

    async def test_chat_api_bot_chat_chat_get(self) -> None:
        """Test case for chat_api_bot_chat_chat_get

        Bot Chat Chat Get
        """
        pass

    async def test_chat_api_bot_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_chat_get_or_create

        Bot Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_chat_topics_list

        Bot Chat Topics List
        """
        pass

    async def test_chat_api_bot_landing_chat_get(self) -> None:
        """Test case for chat_api_bot_landing_chat_get

        Bot Landing Chat Get
        """
        pass

    async def test_chat_api_bot_landing_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_landing_chat_get_or_create

        Bot Landing Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_landing_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_landing_primary_chat_topics_list

        Bot Landing Primary Chat Topics List
        """
        pass

    async def test_chat_api_bot_portal_chat_get(self) -> None:
        """Test case for chat_api_bot_portal_chat_get

        Bot Portal Chat Get
        """
        pass

    async def test_chat_api_bot_portal_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_portal_chat_get_or_create

        Bot Portal Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_primary_chat_topics_list

        Bot Primary Chat Topics List
        """
        pass

    async def test_chat_api_bot_shared_chat_get(self) -> None:
        """Test case for chat_api_bot_shared_chat_get

        Bot Shared Chat Get
        """
        pass

    async def test_chat_api_bot_shared_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_shared_chat_get_or_create

        Bot Shared Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_shared_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_shared_primary_chat_topics_list

        Bot Shared Primary Chat Topics List
        """
        pass

    async def test_chat_api_chat_ai_usage_insert(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert

        Chat Ai Usage Insert
        """
        pass

    async def test_chat_api_chat_ai_usage_insert_v2(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert_v2

        Chat Ai Usage Insert V2
        """
        pass

    async def test_chat_api_chat_delete(self) -> None:
        """Test case for chat_api_chat_delete

        Chat Delete
        """
        pass

    async def test_chat_api_chat_get(self) -> None:
        """Test case for chat_api_chat_get

        Chat Get
        """
        pass

    async def test_chat_api_chat_join(self) -> None:
        """Test case for chat_api_chat_join

        Chat Join
        """
        pass

    async def test_chat_api_chat_leave(self) -> None:
        """Test case for chat_api_chat_leave

        Chat Leave
        """
        pass

    async def test_chat_api_chat_mark_as_read(self) -> None:
        """Test case for chat_api_chat_mark_as_read

        Chat Mark As Read
        """
        pass

    async def test_chat_api_chat_member_ban(self) -> None:
        """Test case for chat_api_chat_member_ban

        Chat Member Ban
        """
        pass

    async def test_chat_api_chat_members_list(self) -> None:
        """Test case for chat_api_chat_members_list

        Chat Members List
        """
        pass

    async def test_chat_api_chat_members_update(self) -> None:
        """Test case for chat_api_chat_members_update

        Chat Members Update
        """
        pass

    async def test_chat_api_chat_message_delete(self) -> None:
        """Test case for chat_api_chat_message_delete

        Chat Message Delete
        """
        pass

    async def test_chat_api_chat_message_get(self) -> None:
        """Test case for chat_api_chat_message_get

        Chat Message Get
        """
        pass

    async def test_chat_api_chat_messages_add(self) -> None:
        """Test case for chat_api_chat_messages_add

        Chat Messages Add
        """
        pass

    async def test_chat_api_chat_messages_insert(self) -> None:
        """Test case for chat_api_chat_messages_insert

        Chat Messages Insert
        """
        pass

    async def test_chat_api_chat_messages_list(self) -> None:
        """Test case for chat_api_chat_messages_list

        Chat Messages List
        """
        pass

    async def test_chat_api_chat_mute(self) -> None:
        """Test case for chat_api_chat_mute

        Chat Mute
        """
        pass

    async def test_chat_api_chat_patch(self) -> None:
        """Test case for chat_api_chat_patch

        Chat Patch
        """
        pass

    async def test_chat_api_chat_private_join(self) -> None:
        """Test case for chat_api_chat_private_join

        Chat Private Join
        """
        pass

    async def test_chat_api_chat_session_feedback_add(self) -> None:
        """Test case for chat_api_chat_session_feedback_add

        Chat Session Feedback Add
        """
        pass

    async def test_chat_api_chat_session_get(self) -> None:
        """Test case for chat_api_chat_session_get

        Chat Session Get
        """
        pass

    async def test_chat_api_chat_session_list_portal(self) -> None:
        """Test case for chat_api_chat_session_list_portal

        Chat Session List Portal
        """
        pass

    async def test_chat_api_chat_session_portal_count(self) -> None:
        """Test case for chat_api_chat_session_portal_count

        Chat Session Portal Count
        """
        pass

    async def test_chat_api_chat_session_start(self) -> None:
        """Test case for chat_api_chat_session_start

        Chat Session Start
        """
        pass

    async def test_chat_api_chat_session_stop(self) -> None:
        """Test case for chat_api_chat_session_stop

        Chat Session Stop
        """
        pass

    async def test_chat_api_chat_unmute(self) -> None:
        """Test case for chat_api_chat_unmute

        Chat Unmute
        """
        pass

    async def test_chat_api_chat_update(self) -> None:
        """Test case for chat_api_chat_update

        Chat Update
        """
        pass

    async def test_chat_api_chats_add(self) -> None:
        """Test case for chat_api_chats_add

        Chats Add
        """
        pass

    async def test_chat_api_chats_list(self) -> None:
        """Test case for chat_api_chats_list

        Chats List
        """
        pass

    async def test_chat_api_chats_list_available(self) -> None:
        """Test case for chat_api_chats_list_available

        Chats List Available
        """
        pass

    async def test_chat_api_contact_chat_get(self) -> None:
        """Test case for chat_api_contact_chat_get

        Contact Chat Get
        """
        pass

    async def test_chat_api_contact_chat_get_or_create(self) -> None:
        """Test case for chat_api_contact_chat_get_or_create

        Contact Chat Get Or Create
        """
        pass

    async def test_chat_api_contact_get(self) -> None:
        """Test case for chat_api_contact_get

        Contact Get
        """
        pass

    async def test_chat_api_contacts_list(self) -> None:
        """Test case for chat_api_contacts_list

        Contacts List
        """
        pass

    async def test_chat_api_feedback_count(self) -> None:
        """Test case for chat_api_feedback_count

        Feedback Count
        """
        pass

    async def test_chat_api_feedback_list(self) -> None:
        """Test case for chat_api_feedback_list

        Feedback List
        """
        pass

    async def test_chat_api_get_total_unread_messages(self) -> None:
        """Test case for chat_api_get_total_unread_messages

        Get Total Unread Messages
        """
        pass

    async def test_chat_api_settings_get(self) -> None:
        """Test case for chat_api_settings_get

        Settings Get
        """
        pass

    async def test_chat_api_settings_set(self) -> None:
        """Test case for chat_api_settings_set

        Settings Set
        """
        pass

    async def test_chat_api_stop_agent_run(self) -> None:
        """Test case for chat_api_stop_agent_run

        Stop Agent Run
        """
        pass

    async def test_chat_api_wipe_bots_from_cache(self) -> None:
        """Test case for chat_api_wipe_bots_from_cache

        Wipe Bots From Cache
        """
        pass

    async def test_chat_api_wipe_portal_community_settings_from_cache(self) -> None:
        """Test case for chat_api_wipe_portal_community_settings_from_cache

        Wipe Portal Community Settings From Cache
        """
        pass

    async def test_chat_api_wipe_portal_members_from_cache(self) -> None:
        """Test case for chat_api_wipe_portal_members_from_cache

        Wipe Portal Members From Cache
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.api.bots_api import BotsApi


class TestBotsApi(unittest.IsolatedAsyncioTestCase):
    """BotsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = BotsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_bot_chat_by_topic_slug(self) -> None:
        """Test case for chat_api_bot_chat_by_topic_slug

        Bot Chat By Topic Slug
        """
        pass

    async def test_chat_api_bot_chat_chat_get(self) -> None:
        """Test case for chat_api_bot_chat_chat_get

        Bot Chat Chat Get
        """
        pass

    async def test_chat_api_bot_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_chat_get_or_create

        Bot Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_chat_topics_list

        Bot Chat Topics List
        """
        pass

    async def test_chat_api_bot_landing_chat_get(self) -> None:
        """Test case for chat_api_bot_landing_chat_get

        Bot Landing Chat Get
        """
        pass

    async def test_chat_api_bot_landing_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_landing_chat_get_or_create

        Bot Landing Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_landing_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_landing_primary_chat_topics_list

        Bot Landing Primary Chat Topics List
        """
        pass

    async def test_chat_api_bot_portal_chat_get(self) -> None:
        """Test case for chat_api_bot_portal_chat_get

        Bot Portal Chat Get
        """
        pass

    async def test_chat_api_bot_portal_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_portal_chat_get_or_create

        Bot Portal Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_primary_chat_topics_list

        Bot Primary Chat Topics List
        """
        pass

    async def test_chat_api_bot_shared_chat_get(self) -> None:
        """Test case for chat_api_bot_shared_chat_get

        Bot Shared Chat Get
        """
        pass

    async def test_chat_api_bot_shared_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_shared_chat_get_or_create

        Bot Shared Chat Get Or Create
        """
        pass

    async def test_chat_api_bot_shared_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_shared_primary_chat_topics_list

        Bot Shared Primary Chat Topics List
        """
        pass


if __name__ == '__main__':
    unittest.main()
